@@ -154,7 +154,7 @@ void* item_gamma_correction() {
   CImgDisplay disp(visu,"[#5] - Gamma Corrected Image and Histogram (Click to set Gamma)");
   const unsigned char
     yellow[] = { 255, 255, 0 }, blue[] = { 0, 155, 255 }, blue2[] = { 0, 0, 255 },
-    blue3[] = { 0, 0, 155 }, white[] = { 255, 255, 255 }, green[] = { 100, 255, 100 };
+    blue3[] = { 0, 0, 155 }, white[] = { 255, 255, 255 }, green[] = { 50, 128, 50 };
 
   for (double gamma = 1; !disp.is_closed() && !disp.is_keyQ() && !disp.is_keyESC(); ) {
     cimg_forXYZC(visu[0],x,y,z,k) visu[0](x,y,z,k) = (unsigned char)(std::pow((double)img(x,y,z,k),1.0/gamma)*256);
@@ -290,7 +290,7 @@ void* item_mandelbrot_explorer() {
                                                  "  ENTER         Switch Mandelbrot/Julia sets  \n"
                                                  "  Arrows        Change set parameterization  \n"
                                                  "  Page UP/DOWN  Add/Reduce iteration numbers  \n\n",
-                                                 white);
+                                                 white).resize(-100,-100,1,3);
         help.draw_rectangle(2,2,help.width() - 3,help.height() - 3,white,1,~0U);
         img.draw_image(img.width() - help.width(),help,0.7f);
       }
@@ -566,7 +566,7 @@ void* item_plasma() {
 
   visu.draw_text(10,10,"Please wait, generating plasma...",white).display(disp);
   const unsigned int nb_plasmas = 5;
-  plasma.assign(5*visu.width()/3,visu.height(),1,nb_plasmas,0).noise(100).draw_plasma();
+  plasma.assign(5*visu.width()/3,visu.height()+1,1,nb_plasmas,0).noise(100).draw_plasma();
   cimg_forC(plasma,k) plasma.get_shared_channel(k).blur((float)(cimg::rand()*6)).normalize(0,255);
 
   while (!disp.is_closed() && !disp.is_keyQ() && !disp.is_keyESC()) {
@@ -585,11 +585,11 @@ void* item_plasma() {
     unsigned char *ptr_r = visu.data(0,0,0,0), *ptr_g = visu.data(0,0,0,1), *ptr_b = visu.data(0,0,0,2);
     cimg_forY(visu,y) {
       const float
-        *ptr_r1 = plasma.data((unsigned int)(camp(0)*(1 + std::sin(tx+cfreq(0)*y))),y,v0),
-        *ptr_g1 = plasma.data((unsigned int)(camp(1)*(1 + std::sin(tx+cfreq(1)*y))),y,v1),
+        *ptr_r1 = plasma.data((unsigned int)(camp(0)*(1.1 + std::sin(tx+cfreq(0)*y))),y,v0),
+        *ptr_g1 = plasma.data((unsigned int)(camp(1)*(1.1 + std::sin(tx+cfreq(1)*y))),y,v1),
         *ptr_b1 = plasma.data((unsigned int)(camp(2)*(2 + std::sin(tx+cfreq(2)*y))),y,v2),
-        *ptr_r2 = plasma.data((unsigned int)(namp(0)*(1 + std::sin(tx+nfreq(0)*y))),y,v1),
-        *ptr_g2 = plasma.data((unsigned int)(namp(1)*(1 + std::sin(tx+nfreq(1)*y))),y,v2),
+        *ptr_r2 = plasma.data((unsigned int)(namp(0)*(1.1 + std::sin(tx+nfreq(0)*y))),y,v1),
+        *ptr_g2 = plasma.data((unsigned int)(namp(1)*(1.1 + std::sin(tx+nfreq(1)*y))),y,v2),
         *ptr_b2 = plasma.data((unsigned int)(namp(2)*(2 + std::sin(tx+nfreq(2)*y))),y,v3);
       cimg_forX(visu,x) {
         *(ptr_r++) = (unsigned char)(umalpha*(*(ptr_r1++)) + alpha*(*(ptr_r2++)));
@@ -855,7 +855,7 @@ void* item_blobs_editor() {
                      "* Colors and size of Appearing Blobs\n"
                      "  are randomly chosen.\n\n\n"
                      " >> Press mouse button to start ! <<",
-                     white);
+                     white).resize(-100,-100,1,3);
       img.fill(100).draw_image((img.width() - text.width())/2,
                                (img.height() - text.height())/2,
                                text,text,1,255U);
@@ -899,7 +899,6 @@ void* item_double_torus() {
   cimglist_for(primitives,l) if (l%2) colors[primitives.size()+l].fill(255,200,255); else colors[primitives.size()+l].fill(200,150,255);
   const CImg<float> opacities = CImg<>(primitives.size(),1,1,1,1.0f).append(CImg<>(primitives.size(),1,1,1,0.4f));
   points.shift_object3d(-30,0,0).append_object3d(primitives,points2.shift_object3d(30,0,0),primitives);
-  points.is_object3d(primitives,true,true);
   float alpha = 0, beta = 0, gamma = 0, theta = 0;
   while (!disp.is_closed() && !disp.is_keyQ() && !disp.is_keyESC()) {
     visu.get_shared_channels(1,2).fill(0);
@@ -1056,7 +1055,7 @@ void* item_rubber_logo() {
     else { if (x<51) colors[l] = CImg<unsigned char>::vector(100,255,155);
     }}}
   faces.reverse_object3d();
-  (points.shift_object3d()*=5.5f).is_object3d(faces,true,true);
+  points.shift_object3d()*=5.5f;
 
   CImgList<unsigned char> frames(100,background);
   bool ok_visu = false;
@@ -1072,7 +1071,6 @@ void* item_rubber_logo() {
       (1+0.1f*std::cos((double)(gamma+=0.1f)));
     (frame=background).draw_object3d(frame.width()/2.0f,frame.height()/2.0f,frame.depth()/2.0f,rot*points,faces,colors,5,
                                      false,500,0,0,-5000,0.1f,1.0f);
-
     if (ok_visu) {
       CImg<unsigned char> visu(frame);
       cimglist_for(frames,l) {
@@ -1231,15 +1229,16 @@ void* item_3d_reflection() {
   cimg_forC(back,k) { back(399,0,k) = back(0,0,k) = 50*((k+1)%2); back(399,399,k) = back(0,399,k) = 20*k; }
   back.draw_plasma().blur(6,1,0).shift(-200,0,0,0,2).blur(6,1,0);
   CImg<unsigned char> light0 = back.get_resize(-50,-50,1,1), visu(back), reflet(back.width(),back.height(),1,1), light(light0);
-  back.get_shared_channel(0)/=3; back.get_shared_channel(2)/=2;
+  back.get_shared_channel(0)/=3;
+  back.get_shared_channel(2)/=2;
 
   // Create 3D objects.
   CImgList<unsigned int> back_faces, main_faces;
   CImgList<unsigned char> main_colors, back_colors, light_colors, light_colors2;
   CImgList<float> back_pts0, main_pts = CImg<>::torus3d(main_faces,30,12,24,12)<'x';
   cimglist_for(main_faces,l)
-    if (l%2) main_colors.insert(CImg<unsigned char>::vector(255,120,16));
-    else main_colors.insert(CImg<unsigned char>::vector(255,100,16));
+    if (l%2) CImg<unsigned char>::vector(255,120,16).move_to(main_colors);
+    else CImg<unsigned char>::vector(255,100,16).move_to(main_colors);
 
   const unsigned int res1 = 32, res2 = 32;
   for (unsigned int v = 1; v<res2; ++v) for (unsigned int u = 0; u<res1; ++u) {
@@ -1267,8 +1266,8 @@ void* item_3d_reflection() {
     if (uu%2) back_colors.insert(2,CImg<unsigned char>::vector(128,255,255));
     else back_colors.insert(2,CImg<unsigned char>::vector(64,240,196));
   }
-  light_colors.assign(back_faces.size(),CImg<unsigned char>::vector(255));
-  light_colors2.assign(light_colors).insert(light,light_colors.size(),true);
+  light_colors.assign(main_faces.size(),CImg<unsigned char>::vector(255));
+  light_colors2.assign(back_faces.size(),CImg<unsigned char>::vector(255)).insert(light,~0U,true);
 
   // Start 3D animation.
   for (float main_x = -1.5f*visu.width(),
@@ -1283,10 +1282,12 @@ void* item_3d_reflection() {
     CImg<float>
       rmain_pts = (CImg<>::rotation_matrix(-1,1,0,main_alpha)*CImg<>::rotation_matrix(1,0,1,main_beta))*(main_pts>'x'),
       rback_pts = (CImg<>::rotation_matrix(1,1,0,back_alpha)*CImg<>::rotation_matrix(0.5,0,1,back_beta))*back_pts;
+
     (light=light0).draw_object3d(main_X/2.0f,main_Y/2.0f,0,rmain_pts,main_faces,light_colors,3,false,500,0,0,-5000,0.2f,0.1f);
     reflet.fill(0).draw_object3d(2*visu.width()/3.0f,visu.height()/2.0f,0,rback_pts,back_faces,light_colors2,5,false,500,0,0,-5000,0.2f,0.1f);
     rmain_pts*=2;
     (visu=back).draw_object3d(2*visu.width()/3.0f,visu.height()/2.0f,0,rback_pts,back_faces,back_colors,3,false,500,0,0,-5000,0.2f,0.1f);
+
     unsigned char *ptrs = reflet.data(), *ptrr = visu.data(0,0,0,0), *ptrg = visu.data(0,0,0,1), *ptrb = visu.data(0,0,0,2);
     cimg_forXY(visu,x,y) {
       const unsigned char v = *(ptrs++);
@@ -1448,7 +1449,7 @@ void* item_word_puzzle() {
       *const mention2 = "Not so bad !", *const mention3 = "  Good !", *const mention4 = "Very good !",
       *const mention5 = " Expert !",
       *mention = completed?(timer<700?mention5:timer<800?mention4:timer<900?mention3:timer<1000?mention2:timer<1200?mention1:mention0):mention0;
-    canvas.assign().draw_text(0,0,"Final time : %d\n\n%s",white,0,1,32,timer,mention);
+    canvas.assign().draw_text(0,0,"Final time : %d\n\n%s",white,0,1,32,timer,mention).resize(-100,-100,1,3);
     ((background/=2)&CImg<unsigned char>(2,2).fill(0,255,255,0).resize(background,0,2)).
       draw_image((background.width()-canvas.width())/2,(background.height()-canvas.height())/2,
                  canvas,canvas.get_dilate(3).dilate(3).dilate(3),1,255).display(disp.flush());
@@ -1559,7 +1560,7 @@ int main(int argc, char **argv) {
                    "25- 3D Reflection\n"
                    "26- Fish-Eye Magnification\n"
                    "27- Word Puzzle\n",
-                   white,0,1,13);
+                   white,0,1,13).resize(-100,-100,1,3);
     fore.resize(back,0).draw_image(20,y0+2*13,text|=text.get_dilate(3)>>4);
 
     CImgDisplay disp(back,"CImg Library Samples",0,false,true);
