@@ -71,7 +71,7 @@ int main(int argc, char **argv) {
 
   // Define game colors and variables
   //----------------------------------
-  const unsigned char green[] = { 64,255,32 }, blue[] = { 128,200,255}, red[] = { 255,0,0 }, white[] = { 255,255,255 };
+  const unsigned char blue[] = { 128,200,255}, red[] = { 255,0,0 }, white[] = { 255,255,255 };
   int score1=0, score2=0, round_over=0, ix1=-1, iy1=-1, x1=0, y1=0, u1=0, v1=0, ix2=-1, iy2=-1, x2=0, y2=0, u2=0, v2=0;
   bool start_round = true, turbo1 = false, turbo2 = false;
 
@@ -103,7 +103,7 @@ int main(int argc, char **argv) {
 
       // Display a simple pre-round page
       CImg<unsigned char> logo, pressakey;
-      logo.draw_text(0,0," CImg-Tron ",green,0,1,32);
+      logo.draw_text(0,0," CImg-Tron ",white,0,1,32).resize(-100,-100,1,3);
       CImg<unsigned char> tmp = (+background).draw_image((W-logo.width())/2,(H-logo.height())/2-20,logo,logo.get_channel(0).dilate(6).normalize(0,1)).
         draw_text(W/2-60,H/2+10,"Blue ( %u )",blue,0,1,13,score1).
         draw_text(W/2+10,H/2+10,"Red ( %u )",red,0,1,13,score2);
