@@ -47,13 +47,13 @@
 
  IMPORTANT NOTE :
 
- You *need* to include the following two lines in your own code to use this plugin :
+ You *need* to include the following lines in your own code to use this plugin :
 
  #include <cstdio>
  #include <jpeglib.h>
  #include <jerror.h>
 
- (see example file provided in examples/jpeg_buffer.cpp).
+ (see example file provided in examples/use_jpeg_buffer.cpp).
 
 ------------------------------------------------------------------------------------*/
 
@@ -364,8 +364,8 @@ const CImg& save_jpeg_buffer(JOCTET *const buffer, unsigned int &buffer_size, co
   }
   jpeg_finish_compress(&cinfo);
   delete[] buf;
-  jpeg_destroy_compress(&cinfo);
   buffer_size = jpeg_mem_size(&cinfo);
+  jpeg_destroy_compress(&cinfo);
   return *this;
 }
 
